@@ -52,8 +52,8 @@ gtr_actions_edit_undo (GtrWindow * window)
     GTK_SOURCE_BUFFER (gtk_text_view_get_buffer
                        (GTK_TEXT_VIEW (active_view)));
 
-  if (gtk_source_buffer_can_undo (active_document))
-    gtk_source_buffer_undo (active_document);
+  if (gtk_text_buffer_get_can_undo (GTK_TEXT_BUFFER(active_document)))
+    gtk_text_buffer_undo (GTK_TEXT_BUFFER(active_document));
 
   gtk_widget_grab_focus (GTK_WIDGET (active_view));
   g_signal_emit_by_name (current, "message_changed", msg->data);
@@ -79,8 +79,8 @@ gtr_actions_edit_redo (GtrWindow * window)
     GTK_SOURCE_BUFFER (gtk_text_view_get_buffer
                        (GTK_TEXT_VIEW (active_view)));
 
-  if (gtk_source_buffer_can_redo (active_document))
-    gtk_source_buffer_redo (active_document);
+  if (gtk_text_buffer_get_can_redo (GTK_TEXT_BUFFER(active_document)))
+    gtk_text_buffer_redo (GTK_TEXT_BUFFER(active_document));
 
   gtk_widget_grab_focus (GTK_WIDGET (active_view));
   g_signal_emit_by_name (current, "message_changed", msg->data);
