@@ -26,9 +26,9 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <gio/gio.h>
 #include <string.h>
 #include <gio/gio.h>
+#include <adwaita.h>
 
 #include "gtr-profile-manager.h"
 #include "gtr-close-confirmation-dialog.h"
@@ -36,7 +36,7 @@
 #include "gtr-application.h"
 #include "gtr-dirs.h"
 #include "gtr-file-dialogs.h"
-#include "gtr-notebook.h"
+//#include "gtr-notebook.h"
 #include "gtr-po.h"
 #include "gtr-tab.h"
 #include "gtr-utils.h"
@@ -66,8 +66,7 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
   GList *current;
   GtrView *active_view;
   GtrHeader *header;
-  GtrNotebook *active_notebook;
-  gchar *dl_team;
+  gchar *dl_lang;
   gchar *dl_module;
   gchar *dl_branch;
   gchar *dl_domain;
@@ -92,7 +91,7 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
   }
 
   header = gtr_po_get_header (po);
-  dl_team = gtr_header_get_dl_team (header);
+  dl_lang = gtr_header_get_dl_lang (header);
   dl_module = gtr_header_get_dl_module (header);
   dl_branch = gtr_header_get_dl_branch (header);
   dl_domain = gtr_header_get_dl_domain (header);
@@ -102,7 +101,7 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
    * Set Damned Lies info when a po file is opened locally
    */
   gtr_po_set_dl_info(po,
-                     dl_team,
+                     dl_lang,
                      dl_module,
                      dl_branch,
                      dl_domain,
@@ -112,14 +111,13 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
    * Create a page to add to our list of open files
    */
   tab = gtr_window_create_tab (window, po);
-  gtr_window_set_active_tab (window, GTK_WIDGET (tab));
 
   /*
    * Activate the upload file icon if the po file is in the appropriate
    * state as on the vertimus workflow
    */
-  active_notebook = gtr_window_get_notebook (window);
-  gtr_notebook_enable_upload (active_notebook, gtr_po_can_dl_upload (po));
+  //active_notebook = gtr_window_get_notebook (window);
+  gtr_tab_enable_upload (tab, gtr_po_can_dl_upload (po));
 
   /*
    * Show the current message.
@@ -139,180 +137,146 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
 }
 
 static void
-gtr_po_parse_files_from_dialog (GtkNativeDialog * dialog, GtrWindow * window)
+gtr_po_parse_files_from_dialog (GObject *source, GAsyncResult *res, void *user_data)
 {
-  GSList *po_files, *l;
   GSList *locations = NULL;
-  GFile *file, *parent;
-  gchar *uri;
+  GtkFileDialog *dialog = GTK_FILE_DIALOG (source);
+  GtrWindow *window = GTR_WINDOW (user_data);
 
-  po_files = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (dialog));
-  for (l = po_files; l != NULL; l = g_slist_next (l))
-    {
-      GFile *file;
+  g_autoptr (GFile) file = NULL;
+  g_autoptr (GFile) parent = NULL;
+  g_autofree gchar *uri = NULL;
 
-      file = g_file_new_for_uri (l->data);
-      locations = g_slist_prepend (locations, file);
-    }
-
-  /*
-   * We store latest directory
-   */
-  file = g_file_new_for_uri (po_files->data);
-  g_slist_free_full (po_files, g_free);
+  // FIXME: handle errors here
+  file = gtk_file_dialog_open_finish (dialog, res, NULL);
+  if (!file) return;
 
   parent = g_file_get_parent (file);
-  g_object_unref (file);
-
   uri = g_file_get_uri (parent);
-  g_object_unref (parent);
   _gtr_application_set_last_dir (GTR_APP, uri);
 
-  g_free (uri);
-
   /*
    * Open the file via our centralized opening function.
    */
-  load_file_list (window, (const GSList *) locations);
-  g_slist_free_full (locations, g_object_unref);
+  locations = g_slist_append (locations, file);
+  load_file_list (window, locations);
 }
 
-
 static void
-gtr_file_chooser_cb (GtkNativeDialog * dialog, guint reply, gpointer user_data)
+handle_save_current_dialog_response (AdwMessageDialog *dialog,
+                                     char *response,
+                                     void (*callback)(GtrWindow *))
 {
-  GtrWindow *window = GTR_WINDOW (user_data);
+  GtrWindow *window = gtr_application_get_active_window (GTR_APP);
 
-  if (reply == GTK_RESPONSE_ACCEPT)
-    gtr_po_parse_files_from_dialog (dialog, window);
+  if (g_strcmp0 ("save", response) == 0)
+    gtr_save_current_file_dialog (NULL, window);
 
-  gtk_native_dialog_destroy (dialog);
+  // callback for "save", "close", and "no"
+  if (g_strcmp0 ("cancel", response) != 0)
+    callback (window);
+
+  gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
-gboolean
-gtr_want_to_save_current_dialog (GtrWindow * window)
+void
+gtr_want_to_save_current_dialog (GtrWindow * window, void (*callback)(GtrWindow *))
 {
-  gint res = 0;
   GtrTab *tab;
   GtrPo *po;
 
   GtkWidget *dialog;
   g_autoptr (GFile) location = NULL;
-  g_autofree gchar *filename = NULL;
-  g_autofree gchar *markup = NULL;
-
-  GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
+  g_autofree gchar *basename = NULL;
 
   tab = gtr_window_get_active_tab (window);
   po = gtr_tab_get_po (tab);
   location = gtr_po_get_location (po);
-  filename = g_file_get_path (location);
+  basename = g_file_get_basename (location);
 
-  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                   flags,
-                                   GTK_MESSAGE_WARNING,
-                                   GTK_BUTTONS_NONE, NULL);
+  dialog = adw_message_dialog_new (GTK_WINDOW (window), _("Unsaved Changes"), NULL);
 
-  markup = g_strdup_printf (
-    _("Do you want to save changes to this file: "
-      "<span weight=\"bold\" size=\"large\">%s</span>?"),
-    filename);
+  adw_message_dialog_set_body_use_markup (ADW_MESSAGE_DIALOG (dialog), TRUE);
 
-  gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
-  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-    _("If you don't save, all your unsaved changes will be permanently lost."));
+  adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog),
+                                  _("Do you want to write all the changes done to %s?"),
+                                  basename);
 
-  gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                          _("Save and open"), GTK_RESPONSE_YES,
-                          _("Cancel"), GTK_RESPONSE_CANCEL,
-                          _("Continue without saving"), GTK_RESPONSE_NO,
-                          NULL);
+  adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
+                                    "cancel", _("Cancel"),
+                                    "no", _("Continue Without Saving"),
+                                    "save", _("Save and Open"),
+                                    NULL);
+  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog),
+    "no", ADW_RESPONSE_DESTRUCTIVE);
+  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog),
+    "save", ADW_RESPONSE_SUGGESTED);
+  adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dialog), "save");
 
-  res = gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_destroy (dialog);
-
-  if (res == GTK_RESPONSE_CANCEL)
-    return FALSE;
-
-  if (res == GTK_RESPONSE_YES)
-    gtr_save_current_file_dialog (NULL, window);
-
-  return TRUE;
+  g_signal_connect (dialog, "response", G_CALLBACK (handle_save_current_dialog_response), callback);
+  gtk_window_present (GTK_WINDOW (dialog));
 }
 
 /*
  * The "Open file" dialog.
  */
-void
-gtr_open_file_dialog (GtrWindow * window)
+static void
+gtr_open_file_dialog_nocheck (GtrWindow *window)
 {
-  GtkNativeDialog *dialog;
-  g_autoptr (GList) list = NULL;
-  list = get_modified_documents (window);
-  if (list != NULL)
-    {
-      if (!gtr_want_to_save_current_dialog (window))
-        return;
-    }
+  GtkFileDialog *dialog;
 
   dialog = gtr_file_chooser_new (GTK_WINDOW (window),
                                  FILESEL_OPEN,
                                  _("Open file for translation"),
                                  _gtr_application_get_last_dir (GTR_APP));
 
-  g_signal_connect (dialog, "response", G_CALLBACK (gtr_file_chooser_cb), window);
-  gtk_native_dialog_show (dialog);
+  gtk_file_dialog_open (dialog, GTK_WINDOW (window), NULL, gtr_po_parse_files_from_dialog, window);
+}
+
+void
+gtr_open_file_dialog (GtrWindow *window)
+{
+  g_autoptr (GList) list = NULL;
+  list = get_modified_documents (window);
+  if (list != NULL)
+    gtr_want_to_save_current_dialog (window, gtr_open_file_dialog_nocheck);
+  else
+    gtr_open_file_dialog_nocheck (window);
 }
 
 static void
-save_dialog_response_cb (GtkNativeDialog * dialog,
-                         gint response_id, GtrWindow * window)
+save_dialog_response_cb (GObject *source, GAsyncResult *res, void *user_data)
 {
   GError *error = NULL;
   GtrPo *po;
   GtrTab *tab;
-  gchar *filename;
-  GFile *location;
+  GtkFileDialog *dialog = GTK_FILE_DIALOG (source);
+  GtrWindow *window = GTR_WINDOW (user_data);
+
+  g_autofree char *filename = NULL;
+  g_autoptr (GFile) file = NULL;
+  g_autoptr (GFile) location = NULL;
 
   tab = gtr_window_get_active_tab (window);
-
-  g_return_if_fail (GTK_IS_FILE_CHOOSER (dialog));
-
   po = gtr_tab_get_po (tab);
 
-  if (response_id != GTK_RESPONSE_ACCEPT)
-    {
-      gtk_native_dialog_destroy (dialog);
-      return;
-    }
-
-  filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-  g_return_if_fail (filename != NULL);
-
+  // FIXME: handle errors here
+  file = gtk_file_dialog_save_finish (dialog, res, NULL);
+  if (!file) return;
+  filename = g_file_get_path (file);
   location = g_file_new_for_path (filename);
-  g_free (filename);
-
-  gtk_native_dialog_destroy (dialog);
 
   if (po != NULL)
     {
       gtr_po_set_location (po, location);
-
       g_object_unref (location);
-
       gtr_po_save_file (po, &error);
 
       if (error)
         {
-          GtkWidget *dialog;
-          GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
-          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                           flags,
-                                           GTK_MESSAGE_WARNING,
-                                           GTK_BUTTONS_OK,
-                                           "%s", error->message);
-          g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-          gtk_window_present (GTK_WINDOW (dialog));
+          GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
+          gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
+          g_object_unref (dialog);
           g_clear_error (&error);
           return;
         }
@@ -333,9 +297,8 @@ _upload_file_callback (GObject      *object,
 {
   UserData *ud = user_data;
   g_autoptr(GInputStream) stream = NULL;
-  GtkWidget *dialog;
-  GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
-  GtrNotebook *active_notebook;
+  GtkAlertDialog *dialog;
+  GtrTab *active_tab;
 
   GtkWidget *upload_dialog = ud->dialog;
   GtkWidget *window = gtr_upload_dialog_get_parent (GTR_UPLOAD_DIALOG (upload_dialog));
@@ -346,18 +309,14 @@ _upload_file_callback (GObject      *object,
 
   stream = soup_session_send_finish (session, result, &error);
 
-  active_notebook = gtr_window_get_notebook (GTR_WINDOW (window));
+  active_tab = gtr_window_get_active_tab (GTR_WINDOW (window));
 
   if (error || !SOUP_STATUS_IS_SUCCESSFUL (status_code))
     {
       if (status_code == SOUP_STATUS_FORBIDDEN)
         {
-          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                           flags,
-                                           GTK_MESSAGE_INFO,
-                                           GTK_BUTTONS_OK,
-                                           _("This file has already been uploaded"));
-          gtr_notebook_enable_upload (active_notebook, FALSE);
+          dialog = gtk_alert_dialog_new (_("This file has already been uploaded"));
+          gtr_tab_enable_upload (active_tab, FALSE);
           goto end;
         }
 
@@ -373,11 +332,7 @@ _upload_file_callback (GObject      *object,
           message = g_strdup (soup_status_get_phrase (status_code));
         }
 
-      dialog = gtk_message_dialog_new_with_markup (
-        GTK_WINDOW (window),
-        flags,
-        GTK_MESSAGE_WARNING,
-        GTK_BUTTONS_CLOSE,
+      dialog = gtk_alert_dialog_new (
         _(
           "An error occurred while uploading the file: %s\n"
           "Maybe you've not configured your <i>l10n.gnome.org</i> "
@@ -388,24 +343,19 @@ _upload_file_callback (GObject      *object,
       goto end;
     }
 
-  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                   flags,
-                                   GTK_MESSAGE_INFO,
-                                   GTK_BUTTONS_OK,
-                                   _("The file has been uploaded!"));
-
-  gtr_notebook_enable_upload (active_notebook, FALSE);
+  dialog = gtk_alert_dialog_new (_("The file has been uploaded!"));
+  gtr_tab_enable_upload (active_tab, FALSE);
 
 end:
-  g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-  gtk_window_present (GTK_WINDOW (dialog));
-  gtk_widget_destroy (upload_dialog);
+  gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
+  g_object_unref (dialog);
+
+  gtk_window_destroy (GTK_WINDOW (upload_dialog));
   g_free (ud);
 }
 
 void
 gtr_upload_file (GtkWidget *upload_dialog,
-                 int        response_id,
                  gpointer   user_data)
 {
   GtrTab *tab;
@@ -428,19 +378,12 @@ gtr_upload_file (GtkWidget *upload_dialog,
   g_autofree char *auth = NULL;
   g_autofree char *upload_comment = NULL;
   gsize size;
-  const gchar *selected_team;
+  const gchar *selected_lang;
   const gchar *selected_module;
   const gchar *selected_branch;
   const gchar *selected_domain;
 
   GtrWindow * window = GTR_WINDOW (user_data);
-
-  if (response_id != GTK_RESPONSE_ACCEPT)
-    {
-      gtk_widget_destroy (upload_dialog);
-      return;
-    }
-
   upload_comment = gtr_upload_dialog_get_comment (GTR_UPLOAD_DIALOG (upload_dialog));
 
   /* Get file content */
@@ -477,16 +420,16 @@ gtr_upload_file (GtkWidget *upload_dialog,
   if (selected_domain == NULL)
     selected_domain = gtr_header_get_dl_domain (header);
 
-  selected_team = gtr_po_get_dl_team (po);
-  if (selected_team == NULL)
-    selected_team = gtr_header_get_dl_team (header);
+  selected_lang = gtr_po_get_dl_lang (po);
+  if (selected_lang == NULL)
+    selected_lang = gtr_header_get_dl_lang (header);
 
-  /* API endpoint: modules/[module]/branches/[branch]/domains/[domain]/languages/[team]/upload */
+  /* API endpoint: modules/[module]/branches/[branch]/domains/[domain]/languages/[lang]/upload */
   upload_endpoint = g_strconcat((const gchar *)API_URL,
                                 "modules/", selected_module,
                                 "/branches/", selected_branch,
                                 "/domains/", selected_domain,
-                                "/languages/", selected_team,
+                                "/languages/", selected_lang,
                                 "/upload", NULL);
 
   /* Init multipart container */
@@ -530,7 +473,7 @@ gtr_upload_file_dialog (GtrWindow * window)
                    G_CALLBACK (gtr_upload_file),
                    window);
 
-  gtk_widget_show_all (GTK_WIDGET (dialog));
+  gtk_window_present (GTK_WINDOW (dialog));
 }
 
 /*
@@ -539,16 +482,13 @@ gtr_upload_file_dialog (GtrWindow * window)
 void
 gtr_save_file_as_dialog (GtrWindow * window)
 {
-  GtkNativeDialog *dialog;
+  GtkFileDialog *dialog;
 
   dialog = gtr_file_chooser_new (GTK_WINDOW (window),
                                  FILESEL_SAVE,
-                                 _("Save file as…"),
-                                 g_get_home_dir ());
+                                 _("Save file as…"), NULL);
 
-  g_signal_connect (dialog, "response", G_CALLBACK (save_dialog_response_cb),
-                    window);
-  gtk_native_dialog_show (dialog);
+  gtk_file_dialog_save (dialog, GTK_WINDOW (window), NULL, save_dialog_response_cb, window);
 }
 
 /*
@@ -568,14 +508,9 @@ gtr_save_current_file_dialog (GtkWidget * widget, GtrWindow * window)
 
   if (error)
     {
-      GtkWidget *dialog;
-      GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
-      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                       flags,
-                                       GTK_MESSAGE_WARNING,
-                                       GTK_BUTTONS_OK, "%s", error->message);
-      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-      gtk_window_present (GTK_WINDOW (dialog));
+      GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
+      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
+      g_object_unref (dialog);
       g_clear_error (&error);
       return;
     }
@@ -584,63 +519,17 @@ gtr_save_current_file_dialog (GtkWidget * widget, GtrWindow * window)
   gtr_po_set_state (po, GTR_PO_STATE_SAVED);
 }
 
-static gboolean
-is_duplicated_location (const GSList * locations, GFile * u)
-{
-  GSList *l;
-
-  for (l = (GSList *) locations; l != NULL; l = g_slist_next (l))
-    {
-      if (g_file_equal (u, l->data))
-        return TRUE;
-    }
-
-  return FALSE;
-}
-
 static void
 load_file_list (GtrWindow * window, const GSList * locations)
 {
   GSList *locations_to_load = NULL;
-  const GSList *l;
   GError *error = NULL;
-  GtkWidget *tab;
 
   g_return_if_fail ((locations != NULL) && (locations->data != NULL));
 
-  // removing other tabs, for now on, we'll using single tab and multiples windows
-  gtr_window_remove_all_pages (window);
+  gtr_window_remove_tab (window);
 
-  /* Remove the uris corresponding to documents already open
-   * in "window" and remove duplicates from "uris" list */
-  l = locations;
-  while (locations != NULL)
-    {
-      if (!is_duplicated_location (locations_to_load, locations->data))
-        {
-          /*We need to now if is already loaded in any tab */
-          tab = gtr_window_get_tab_from_location (window,
-                                                  (GFile *) locations->data);
-
-          if (tab != NULL)
-            {
-              if (locations == l)
-                gtr_window_set_active_tab (window, tab);
-            }
-          else
-            locations_to_load = g_slist_prepend (locations_to_load,
-                                                 locations->data);
-
-        }
-
-      locations = g_slist_next (locations);
-    }
-
-  if (locations_to_load == NULL)
-    return;
-
-  locations_to_load = g_slist_reverse (locations_to_load);
-  l = locations_to_load;
+  locations_to_load = g_slist_reverse ((GSList*) locations);
 
   while (locations_to_load != NULL)
     {
@@ -658,30 +547,20 @@ load_file_list (GtrWindow * window, const GSList * locations)
    */
   if (error != NULL)
     {
-      GtkWidget *dialog;
-      GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
-      /*
-       * We have to show the error in a dialog
-       */
-      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                       flags,
-                                       GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
-                                       "%s", error->message);
-      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-      gtk_window_present (GTK_WINDOW (dialog));
+      GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
+      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
+      g_object_unref (dialog);
       g_error_free (error);
     }
 
-  /* Free uris_to_load. Note that l points to the first element of uris_to_load */
-  g_slist_free ((GSList *) l);
+  g_slist_free ((GSList *) locations_to_load);
 }
 
 
 /**
  * gtr_actions_load_uris:
  *
- * Ignore non-existing URIs 
+ * Ignore non-existing URIs
  */
 void
 gtr_actions_load_locations (GtrWindow * window, const GSList * locations)
@@ -692,140 +571,66 @@ gtr_actions_load_locations (GtrWindow * window, const GSList * locations)
   load_file_list (window, locations);
 }
 
-static void
-save_and_close_document (GtrPo * po, GtrWindow * window)
-{
-  GtrTab *tab;
-
-  gtr_save_current_file_dialog (NULL, window);
-
-  tab = gtr_tab_get_from_document (po);
-
-  _gtr_window_close_tab (window, tab);
-}
-
 static void
 close_all_tabs (GtrWindow * window)
 {
-  GtrNotebook *nb;
-
-  nb = gtr_window_get_notebook (window);
-  gtr_notebook_remove_all_pages (nb);
-
-  //FIXME: This has to change once we add the close all documents menuitem
-  gtk_widget_destroy (GTK_WIDGET (window));
+  gtr_window_remove_tab (window);
+  gtk_window_destroy (GTK_WINDOW (window));
 }
 
 static void
 save_and_close_all_documents (GList * unsaved_documents, GtrWindow * window)
 {
-  GtrTab *tab;
-  GList *l;
   GError *error = NULL;
 
-  for (l = unsaved_documents; l != NULL; l = g_list_next (l))
-    {
-      gtr_po_save_file (l->data, &error);
+  if(unsaved_documents == NULL)
+    return;
 
-      if (error)
-        {
-          GtkWidget *dialog;
-          GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
-          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                           flags,
-                                           GTK_MESSAGE_WARNING,
-                                           GTK_BUTTONS_OK,
-                                           "%s", error->message);
-          g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-          gtk_window_present (GTK_WINDOW (dialog));
-          g_clear_error (&error);
+  gtr_po_save_file (unsaved_documents->data, &error);
 
-          return;
-        }
+  if(error)
+  {
+    GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
+    gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
+    g_object_unref (dialog);
+    g_clear_error (&error);
+    return;
+  }
 
-      tab = gtr_tab_get_from_document (l->data);
-
-      _gtr_window_close_tab (window, tab);
-    }
-
-  gtk_widget_destroy (GTK_WIDGET (window));
+  gtr_window_remove_tab (window);
+  gtk_window_destroy (GTK_WINDOW (window));
 }
 
 static void
-close_confirmation_dialog_response_handler (GtrCloseConfirmationDialog
-                                            * dlg, gint response_id,
-                                            GtrWindow * window)
+close_confirmation_dialog_response_handler (GtrCloseConfirmationDialog *dlg,
+                                            char *response,
+                                            GtrWindow *window)
 {
   GList *selected_documents;
-  gboolean is_closing_all;
-
-  gtk_widget_hide (GTK_WIDGET (dlg));
-
-  is_closing_all = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (window),
-                                                       GTR_IS_CLOSING_ALL));
-
-  switch (response_id)
+  if (g_strcmp0 (response, "yes") == 0)
     {
-    case GTK_RESPONSE_YES:     /* Save and Close */
-      selected_documents =
-        gtr_close_confirmation_dialog_get_selected_documents (dlg);
+      /* Save and Close */
+      selected_documents = gtr_close_confirmation_dialog_get_selected_documents (dlg);
       if (selected_documents == NULL)
         {
-          if (is_closing_all)
-            {
-              gtk_widget_destroy (GTK_WIDGET (dlg));
-
-              close_all_tabs (window);
-
-              return;
-            }
-          else
-            g_return_if_reached ();
-        }
-      else
-        {
-          if (is_closing_all)
-            {
-              save_and_close_all_documents (selected_documents, window);
-            }
-          else
-            {
-              save_and_close_document (selected_documents->data, window);
-            }
-        }
-
-      g_list_free (selected_documents);
-
-      break;
-
-    case GTK_RESPONSE_NO:      /* Close without Saving */
-      if (is_closing_all)
-        {
-          gtk_widget_destroy (GTK_WIDGET (dlg));
-
+          gtk_window_destroy (GTK_WINDOW (dlg));
           close_all_tabs (window);
-
           return;
         }
       else
         {
-          const GList *unsaved_documents;
-
-          unsaved_documents =
-            gtr_close_confirmation_dialog_get_unsaved_documents (dlg);
-          g_return_if_fail (unsaved_documents->next == NULL);
-
-          _gtr_window_close_tab (window,
-                                 gtr_tab_get_from_document
-                                 (unsaved_documents->data));
+          save_and_close_all_documents (selected_documents, window);
         }
-
-      break;
-    default:                   /* Do not close */
-      break;
+      g_list_free (selected_documents);
+    }
+  else if (g_strcmp0 (response, "no") == 0)
+    {
+      gtk_window_destroy (GTK_WINDOW (dlg));
+      close_all_tabs (window);
+      return;
     }
 
-  gtk_widget_destroy (GTK_WIDGET (dlg));
+  gtk_window_destroy (GTK_WINDOW (dlg));
 }
 
 void
@@ -848,10 +653,11 @@ gtr_close_tab (GtrTab * tab, GtrWindow * window)
                         G_CALLBACK
                         (close_confirmation_dialog_response_handler), window);
 
-      gtk_widget_show (dlg);
+      gtk_window_present (GTK_WINDOW (dlg));
     }
   else
-    _gtr_window_close_tab (window, tab);
+    //_gtr_window_close_tab (window, tab);
+    gtr_window_remove_tab(window);
 }
 
 void
@@ -867,13 +673,12 @@ gtr_file_close (GtrWindow * window)
 static GList *
 get_modified_documents (GtrWindow * window)
 {
-  GtrNotebook *nb;
+  //GtrNotebook *nb;
   GtrTab *tab;
   GtrPo *po;
-  gint pages;
   GList *list = NULL;
 
-  nb = gtr_window_get_notebook (window);
+  /*nb = gtr_window_get_notebook (window);
   pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
 
   while (pages > 0)
@@ -886,8 +691,14 @@ get_modified_documents (GtrWindow * window)
         list = g_list_prepend (list, po);
 
       pages--;
-    }
+    }*/
 
+  tab = gtr_window_get_active_tab(window);
+  if (tab != NULL) {
+    po = gtr_tab_get_po (tab);
+    if (gtr_po_get_state (po) == GTR_PO_STATE_MODIFIED)
+      list = g_list_prepend (list, po);
+  }
   return list;
 }
 
@@ -912,7 +723,7 @@ close_all_documents (GtrWindow * window, gboolean logout_mode)
 
       g_list_free (list);
 
-      gtk_widget_show (dlg);
+      gtk_window_present (GTK_WINDOW (dlg));
     }
   else
     {
@@ -920,7 +731,7 @@ close_all_documents (GtrWindow * window, gboolean logout_mode)
 
       if (logout_mode)
         {
-          gtk_widget_destroy (GTK_WIDGET (window));
+          gtk_window_destroy (GTK_WINDOW (window));
         }
     }
 }
@@ -955,16 +766,9 @@ _gtr_actions_file_save_all (GtrWindow * window)
 
       if (error)
         {
-          GtkWidget *dialog;
-          GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
-
-          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                           flags,
-                                           GTK_MESSAGE_WARNING,
-                                           GTK_BUTTONS_OK,
-                                           "%s", error->message);
-          g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-          gtk_window_present (GTK_WINDOW (dialog));
+          GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
+          gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
+          g_object_unref (dialog);
           g_clear_error (&error);
 
           return;
