@@ -38,13 +38,6 @@ typedef struct
 {
   GSettings *settings;
 
-  GtkWidget *main_box;
-  GtkWidget *notebook;
-
-  GtkWidget *prj_page;
-  GtkWidget *lang_page;
-  GtkWidget *lang_vbox;
-
   GtkWidget *prj_id_version;
   GtkWidget *rmbt;
   GtkWidget *prj_comment;
@@ -60,7 +53,7 @@ typedef struct
   GtkWidget *charset;
   GtkWidget *encoding;
 
-  GtkWidget *team;
+  GtkWidget *lang;
   GtkWidget *module;
   GtkWidget *branch;
   GtkWidget *domain;
@@ -71,10 +64,10 @@ typedef struct
 
 struct _GtrHeaderDialog
 {
-  GtkDialog parent_instance;
+  AdwPreferencesWindow parent_instance;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtrHeaderDialog, gtr_header_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrHeaderDialog, gtr_header_dialog, ADW_TYPE_PREFERENCES_WINDOW)
 
 static void
 gtr_header_dialog_dispose (GObject * object)
@@ -91,20 +84,45 @@ static void
 gtr_header_dialog_class_init (GtrHeaderDialogClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->dispose = gtr_header_dialog_dispose;
+
+  gtk_widget_class_set_template_from_resource (widget_class,
+                                               "/org/gnome/translator/gtr-header-dialog.ui");
+
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, take_my_options);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, translator);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, tr_email);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, language);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, lang_code);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, lg_email);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, charset);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, encoding);
+
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, prj_id_version);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, rmbt);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, pot_date);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, po_date);
+
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, prj_comment);
+
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, lang);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, module);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, branch);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, domain);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrHeaderDialog, state);
 }
 
 static void
-take_my_options_checkbutton_toggled (GtkToggleButton * button,
-                                     GtrHeaderDialog * dlg)
+take_my_options_checkbutton_toggled (GtkSwitch *button,
+                                     GParamSpec *spec,
+                                     GtrHeaderDialog *dlg)
 {
   gboolean active;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  g_return_if_fail (button == GTK_TOGGLE_BUTTON (priv->take_my_options));
-
-  active = gtk_toggle_button_get_active (button);
+  active = gtk_switch_get_active (button);
 
   g_settings_set_boolean (priv->settings, GTR_SETTINGS_USE_PROFILE_VALUES,
                           active);
@@ -125,10 +143,10 @@ po_state_set_modified (GtrPo * po)
 }
 
 static void
-prj_comment_changed (GtkTextBuffer * buffer, GtrHeaderDialog * dlg)
+prj_comment_changed (GtkTextBuffer *buffer, GtrHeaderDialog * dlg)
 {
   GtkTextIter start, end;
-  gchar *text;
+  char *text;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
   gtk_text_buffer_get_bounds (buffer, &start, &end);
@@ -143,13 +161,12 @@ prj_comment_changed (GtkTextBuffer * buffer, GtrHeaderDialog * dlg)
 }
 
 static void
-prj_id_version_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
+prj_id_version_changed (GtkEditable *editable, GtrHeaderDialog * dlg)
 {
-  const gchar *text;
+  const char *text;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  text = gtk_entry_get_text (GTK_ENTRY (widget));
-
+  text = gtk_editable_get_text (editable);
   if (text)
     {
       gtr_header_set_prj_id_version (gtr_po_get_header (priv->po), text);
@@ -158,13 +175,12 @@ prj_id_version_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 }
 
 static void
-rmbt_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
+rmbt_changed (GtkEditable *editable, GtrHeaderDialog * dlg)
 {
-  const gchar *text;
+  const char *text;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  text = gtk_entry_get_text (GTK_ENTRY (widget));
-
+  text = gtk_editable_get_text (editable);
   if (text)
     {
       gtr_header_set_rmbt (gtr_po_get_header (priv->po), text);
@@ -173,13 +189,13 @@ rmbt_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 }
 
 static void
-translator_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
+translator_changed (GtkWidget *widget, GtrHeaderDialog * dlg)
 {
-  const gchar *name, *email;
+  const char *name, *email;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  name = gtk_entry_get_text (GTK_ENTRY (priv->translator));
-  email = gtk_entry_get_text (GTK_ENTRY (priv->tr_email));
+  name = gtk_editable_get_text (GTK_EDITABLE (priv->translator));
+  email = gtk_editable_get_text (GTK_EDITABLE (priv->tr_email));
 
   if (name && email)
     {
@@ -191,13 +207,12 @@ translator_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 static void
 language_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 {
-  const gchar *language, *lg_email, *lang_code;
+  const char *language, *lg_email, *lang_code;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  language = gtk_entry_get_text (GTK_ENTRY (priv->language));
-  lg_email = gtk_entry_get_text (GTK_ENTRY (priv->lg_email));
-  lang_code = gtk_entry_get_text (GTK_ENTRY (priv->lang_code));
-
+  language = gtk_editable_get_text (GTK_EDITABLE (priv->language));
+  lg_email = gtk_editable_get_text (GTK_EDITABLE (priv->lg_email));
+  lang_code = gtk_editable_get_text (GTK_EDITABLE (priv->lang_code));
   if (language && lg_email)
     {
       gtr_header_set_language (gtr_po_get_header (priv->po),
@@ -210,16 +225,16 @@ language_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 static void
 dl_changed (GtkWidget * widget, GtrHeaderDialog * dlg)
 {
-  const gchar *team, *module, *branch, *domain;
+  const char *lang, *module, *branch, *domain;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  team = gtk_entry_get_text (GTK_ENTRY (priv->team));
-  module = gtk_entry_get_text (GTK_ENTRY (priv->module));
-  branch = gtk_entry_get_text (GTK_ENTRY (priv->branch));
-  domain = gtk_entry_get_text (GTK_ENTRY (priv->domain));
+  lang = gtk_editable_get_text (GTK_EDITABLE (priv->lang));
+  module = gtk_editable_get_text (GTK_EDITABLE (priv->module));
+  branch = gtk_editable_get_text (GTK_EDITABLE (priv->branch));
+  domain = gtk_editable_get_text (GTK_EDITABLE (priv->domain));
 
   gtr_header_set_dl_info (gtr_po_get_header (priv->po),
-                          team, module, branch,
+                          lang, module, branch,
                           domain);
 
   po_state_set_modified (priv->po);
@@ -229,8 +244,8 @@ static void
 gtr_header_dialog_fill_from_header (GtrHeaderDialog * dlg)
 {
   GtrHeader *header;
-  GtkTextBuffer *buffer;
   gchar *text;
+  GtkTextBuffer *buffer;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
   header = gtr_po_get_header (priv->po);
@@ -240,141 +255,102 @@ gtr_header_dialog_fill_from_header (GtrHeaderDialog * dlg)
   gtk_text_buffer_set_text (buffer, gtr_header_get_comments (header), -1);
 
   text = gtr_header_get_prj_id_version (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->prj_id_version), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->prj_id_version), text);
   g_free (text);
 
   text = gtr_header_get_pot_date (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->pot_date), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->pot_date), text);
   g_free (text);
 
   text = gtr_header_get_po_date (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->po_date), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->po_date), text);
   g_free (text);
 
   text = gtr_header_get_rmbt (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->rmbt), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->rmbt), text);
   g_free (text);
 
   /* Translator and Language Information */
   text = gtr_header_get_translator (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->translator), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->translator), text);
   g_free (text);
 
   text = gtr_header_get_tr_email (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->tr_email), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->tr_email), text);
   g_free (text);
 
   text = gtr_header_get_language (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->language), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->language), text);
   g_free (text);
 
   text = gtr_header_get_language_code (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->lang_code), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->lang_code), text);
   g_free (text);
 
   text = gtr_header_get_lg_email (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->lg_email), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->lg_email), text);
   g_free (text);
 
   text = gtr_header_get_charset (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->charset), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->charset), text);
   g_free (text);
 
   text = gtr_header_get_encoding (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->encoding), text);
+  gtk_editable_set_text (GTK_EDITABLE (priv->encoding), text);
   g_free (text);
 
   /* Damned Lies Information */
-  text = gtr_header_get_dl_team (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->team), text);
-  g_free (text);
+  text = gtr_header_get_dl_lang (header);
+  if (text)
+    {
+      gtk_editable_set_text (GTK_EDITABLE (priv->lang), text);
+      g_free (text);
+    }
 
   text = gtr_header_get_dl_module (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->module), text);
-  g_free (text);
+  if (text)
+    {
+      gtk_editable_set_text (GTK_EDITABLE (priv->module), text);
+      g_free (text);
+    }
 
   text = gtr_header_get_dl_branch (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->branch), text);
-  g_free (text);
+  if (text)
+    {
+      gtk_editable_set_text (GTK_EDITABLE (priv->branch), text);
+      g_free (text);
+    }
 
   text = gtr_header_get_dl_domain (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->domain), text);
-  g_free (text);
+  if (text)
+    {
+      gtk_editable_set_text (GTK_EDITABLE (priv->domain), text);
+      g_free (text);
+    }
 
   text = gtr_header_get_dl_state (header);
-  gtk_entry_set_text (GTK_ENTRY (priv->state), text);
-  g_free (text);
+  if (text)
+    {
+      gtk_editable_set_text (GTK_EDITABLE (priv->state), text);
+      g_free (text);
+    }
 }
 
 static void
 gtr_header_dialog_init (GtrHeaderDialog * dlg)
 {
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
-  GtkBox *content_area;
-  GtkBuilder *builder;
-  gchar *root_objects[] = {
-    "main_box",
-    NULL
-  };
 
   priv->settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
 
-  gtk_dialog_add_buttons (GTK_DIALOG (dlg),
-                          _("_Close"), GTK_RESPONSE_CLOSE, NULL);
-
   gtk_window_set_title (GTK_WINDOW (dlg), _("Edit Header"));
-  gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
+  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 
-  content_area = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg)));
+  gtk_widget_init_template (GTK_WIDGET (dlg));
 
-  gtk_widget_set_margin_start (GTK_WIDGET (dlg), 6);
-  gtk_widget_set_margin_end (GTK_WIDGET (dlg), 6);
-  gtk_widget_set_margin_top (GTK_WIDGET (dlg), 6);
-  gtk_widget_set_margin_bottom (GTK_WIDGET (dlg), 6);
-  gtk_box_set_spacing (content_area, 6);
-
-  g_signal_connect (dlg, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-
-  builder = gtk_builder_new ();
-  gtk_builder_add_objects_from_resource (builder, "/org/gnome/translator/gtr-header-dialog.ui",
-                                         root_objects, NULL);
-
-  priv->main_box = GTK_WIDGET (gtk_builder_get_object (builder, "main_box"));
-  g_object_ref (priv->main_box);
-  priv->notebook = GTK_WIDGET (gtk_builder_get_object (builder, "notebook"));
-  priv->lang_vbox = GTK_WIDGET (gtk_builder_get_object (builder, "lang_vbox"));
-  priv->prj_id_version = GTK_WIDGET (gtk_builder_get_object (builder, "prj_id_version"));
-  priv->rmbt = GTK_WIDGET (gtk_builder_get_object (builder, "rmbt"));
-  priv->prj_comment = GTK_WIDGET (gtk_builder_get_object (builder, "prj_comment"));
-  priv->take_my_options = GTK_WIDGET (gtk_builder_get_object (builder, "take_my_options"));
-  priv->translator = GTK_WIDGET (gtk_builder_get_object (builder, "tr_name"));
-  priv->tr_email = GTK_WIDGET (gtk_builder_get_object (builder, "tr_email"));
-  priv->pot_date = GTK_WIDGET (gtk_builder_get_object (builder, "pot_date"));
-  priv->po_date = GTK_WIDGET (gtk_builder_get_object (builder, "po_date"));
-  priv->language = GTK_WIDGET (gtk_builder_get_object (builder, "language_entry"));
-  priv->lang_code = GTK_WIDGET (gtk_builder_get_object (builder, "language_code_entry"));
-  priv->lg_email = GTK_WIDGET (gtk_builder_get_object (builder, "lg_email_entry"));
-  priv->charset = GTK_WIDGET (gtk_builder_get_object (builder, "charset_entry"));
-  priv->encoding = GTK_WIDGET (gtk_builder_get_object (builder, "encoding_entry"));
-  priv->team = GTK_WIDGET (gtk_builder_get_object (builder, "team"));
-  priv->module = GTK_WIDGET (gtk_builder_get_object (builder, "module"));
-  priv->branch = GTK_WIDGET (gtk_builder_get_object (builder, "branch"));
-  priv->domain = GTK_WIDGET (gtk_builder_get_object (builder, "domain"));
-  priv->state = GTK_WIDGET (gtk_builder_get_object (builder, "state"));
-
-  g_object_unref (builder);
-
-  gtk_box_append (content_area, priv->main_box);
-
-  gtk_widget_set_margin_start (priv->notebook, 6);
-  gtk_widget_set_margin_end (priv->notebook, 6);
-  gtk_widget_set_margin_top (priv->notebook, 6);
-  gtk_widget_set_margin_bottom (priv->notebook, 6);
-
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->take_my_options),
-                                g_settings_get_boolean (priv->settings,
-                                                        GTR_SETTINGS_USE_PROFILE_VALUES));
+  gtk_switch_set_active (GTK_SWITCH (priv->take_my_options),
+                         g_settings_get_boolean (priv->settings, GTR_SETTINGS_USE_PROFILE_VALUES));
 
   gtk_text_view_set_editable (GTK_TEXT_VIEW (priv->prj_comment), TRUE);
 
@@ -383,14 +359,12 @@ gtr_header_dialog_init (GtrHeaderDialog * dlg)
   gtk_widget_set_sensitive (priv->charset, FALSE);
   gtk_widget_set_sensitive (priv->state, FALSE);
 
-  if (gtk_toggle_button_get_active
-      (GTK_TOGGLE_BUTTON (priv->take_my_options)))
+  if (gtk_switch_get_active (GTK_SWITCH (priv->take_my_options)))
     {
       gboolean active;
 
       active =
-        gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-                                      (priv->take_my_options));
+        gtk_switch_get_active (GTK_SWITCH (priv->take_my_options));
 
       gtk_widget_set_sensitive (priv->translator, !active);
       gtk_widget_set_sensitive (priv->tr_email, !active);
@@ -413,12 +387,13 @@ set_default_values (GtrHeaderDialog * dlg, GtrWindow * window)
   priv->po = gtr_tab_get_po (tab);
   gtr_header_dialog_fill_from_header (GTR_HEADER_DIALOG (dlg));
 
+  gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
+
   /*Connect signals */
-  g_signal_connect (priv->take_my_options, "toggled",
+  g_signal_connect (priv->take_my_options, "notify::active",
                     G_CALLBACK (take_my_options_checkbutton_toggled), dlg);
 
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->prj_comment));
-
   g_signal_connect (buffer, "changed", G_CALLBACK (prj_comment_changed), dlg);
 
   /* Connect signals to edit Project information on Header dialog */
@@ -444,7 +419,7 @@ set_default_values (GtrHeaderDialog * dlg, GtrWindow * window)
   g_signal_connect (priv->lg_email, "changed",
                     G_CALLBACK (language_changed), dlg);
 
-  g_signal_connect (priv->team, "changed",
+  g_signal_connect (priv->lang, "changed",
                     G_CALLBACK (dl_changed), dlg);
 
   g_signal_connect (priv->module, "changed",
@@ -460,30 +435,17 @@ set_default_values (GtrHeaderDialog * dlg, GtrWindow * window)
 void
 gtr_show_header_dialog (GtrWindow * window)
 {
-  static GtkWidget *dlg = NULL;
+  GtkWidget *dlg = NULL;
   GtrTab *tab = NULL;
 
+  g_return_if_fail (GTR_IS_WINDOW (window));
   tab = gtr_window_get_active_tab (window);
   g_return_if_fail (tab != NULL);
 
-  g_return_if_fail (GTR_IS_WINDOW (window));
-
-  if (dlg == NULL)
-    {
-      dlg = GTK_WIDGET (g_object_new (GTR_TYPE_HEADER_DIALOG,
-                                      "use-header-bar", TRUE, NULL));
-
-      g_signal_connect (dlg,
-                        "destroy", G_CALLBACK (gtk_widget_destroyed), &dlg);
-
-      set_default_values (GTR_HEADER_DIALOG (dlg), window);
-
-      gtk_widget_show (GTK_WIDGET (dlg));
-    }
+  dlg = GTK_WIDGET (g_object_new (GTR_TYPE_HEADER_DIALOG, NULL));
+  set_default_values (GTR_HEADER_DIALOG (dlg), window);
 
   gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
-  gtk_window_set_type_hint (GTK_WINDOW (dlg), GDK_WINDOW_TYPE_HINT_DIALOG);
   gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
-
   gtk_window_present (GTK_WINDOW (dlg));
 }
